import { Pool, PoolClient } from 'pg';
/**
 * Returns the error as verified Error object or wraps the input as Error.
 * @param error The error variable to check
 * @returns The error if the input was already an error otherwise a wrapped error.
 */
export declare const ensureError: (error: unknown) => Error;
/**
 * Sleep for a given amount of milliseconds
 * @param milliseconds The time in milliseconds to sleep
 * @returns The (void) promise to await
 */
export declare const sleep: (milliseconds: number) => Promise<void>;
/**
 * Run a promise but make sure to wait only a maximum amount of time for it to finish.
 * @param promise The promise to execute
 * @param timeoutMs The amount of time in milliseconds to wait for the promise to finish
 * @param failureMessage The message for the error if the timeout was reached
 * @returns The promise return value or a timeout error is thrown
 */
export declare const awaitWithTimeout: <T>(promise: () => Promise<T>, timeoutMs: number, failureMessage?: string) => Promise<T>;
/**
 * Open a transaction and execute the callback as part of the transaction.
 * @param pool The PostgreSQL database pool
 * @param callback The callback to execute DB commands with.
 * @returns The result of the callback (if any).
 * @throws Any error from the database or the callback.
 */
export declare const executeTransaction: <T>(pool: Pool, callback: (client: PoolClient) => Promise<T>) => Promise<T>;
//# sourceMappingURL=utils.d.ts.map